#
# spec file for package kubeshark-cli
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define executable_name kubeshark

Name:           kubeshark-cli
Version:        52.5.0
Release:        1.2
Summary:        CLI for the API traffic analyzer for Kubernetes
License:        Apache-2.0
URL:            https://github.com/kubeshark/kubeshark
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.22
BuildRequires:  zsh

%description
Kubeshark is an API Traffic Analyzer for Kubernetes providing real-time,
protocol-level visibility into Kubernetes’ internal network, capturing and
monitoring all traffic and payloads going in, out and across containers, pods,
nodes and clusters.

This package contains the kubeshark CLI.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")

go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/kubeshark/kubeshark/misc.GitCommitHash=${COMMIT_HASH} \
   -X github.com/kubeshark/kubeshark/misc.Branch=main \
   -X github.com/kubeshark/kubeshark/misc.Platform=linux \
   -X github.com/kubeshark/kubeshark/misc.Ver=v%{version} \
   -X github.com/kubeshark/kubeshark/misc.BuildTimestamp=${BUILD_DATE}" \
   -o bin/%{executable_name} kubeshark.go

%install
# Install the binary.
install -D -m 0755 bin/%{executable_name} %{buildroot}/%{_bindir}/%{executable_name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{executable_name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{executable_name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{executable_name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{executable_name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{executable_name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{executable_name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{executable_name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{executable_name}

%changelog
* Sun Mar  2 2025 opensuse_buildservice@ojkastl.de
- Update to version 52.5.0:
  * :bookmark: Bump the Helm chart version to 52.5.0
  * Update structs and docs (#1710)
  * :wrench: Add `aiAssistantEnabled` helm value (#1717)
  * :wrench: Enable BPF-override on `tap.packetCapture: af_packet`
    (#1712)
  * Update name of merged file (#1716)
  * Add `demoModeEnabled` helm value (#1714)
  * finished templating `tap.mountBpf` option. (#1711)
* Tue Feb 11 2025 opensuse_buildservice@ojkastl.de
- Update to version 52.4.2:
  A quick patch release for the v52.4 minor branch.
  * Fixed Websocket related panic that was due to an oversized
    message size (#1713).
  * Removed some redundant warnings from the Workers' logs.
  * Optimized Workers CPU consumption.
  * Added KFL selectors the the legend components int he legend
    section in the Service Map.
* Fri Feb  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 52.4.0:
  * :bookmark: Bump the Helm chart version to 52.4.0
  * Worker component security context refactoring  (#1707)
  * Remove init container; remove -disable-ebpf option (#1706)
  * Readme updated (#1705)
  * Fix pull secret aligning (#1703)
  * Refactor and simplify pcapdump logic (#1701)
  * Add `PortMapping` to `TapConfig` for port number based
    dissector prioritization (#1700)
  * Automatic patch updates
  * Moving to eBPF as a default packet capture method. Making
    default packet capture method eBPF, defaulting to AF_PACKET in
    case eBPF is not available
* Sat Jan 25 2025 opensuse_buildservice@ojkastl.de
- Update to version 52.3.96:
  * :bookmark: Bump the Helm chart version to 52.3.96
  * Changed two errors to warnings.
  * Add dns config (#1698)
  * add diameter protocol support (#1696)
  * Make node selector component specific (#1694)
  * added `-disable-tracer` option (#1695)
  * #528 Remove pcap src from configMap (#1693)
  * Add helm variable to disable live config-map user actions
    (#1689)
  * Fix error on getting namespaces for pcap target files (#1691)
  * Fix err when using dest arg (#1688)
* Sat Jan 11 2025 opensuse_buildservice@ojkastl.de
- Update to version 52.3.95:
  * :bookmark: Bump the Helm chart version to 52.3.95
  * Update worker liveness/readiness config (#1684)
  * support new radius protocol (#1682)
  * updated the notes (#1681)
* Sat Jan  4 2025 opensuse_buildservice@ojkastl.de
- Update to version 52.3.94 (52.3.93 was yanked):
  * :sparkles: Update the Helm chart
  * :bookmark: Bump the Helm chart version to 52.3.93
  * extended the https macro to include http2 in addition to http
  * added https as a default macro (#1680)
  * Add `CUSTOM_MACROS` to `ConfigMap` (#1674)
  * Revert "Revert "Initialize kubeshark pinned eBPF resources
    inside init container (#1665)" (#1676)" (#1678)
  * Add save/activate/delete role scripting permissions (#1675)
  * Revert "Initialize kubeshark pinned eBPF resources inside init
    container (#1665)" (#1676)
  * Added security capabilities, especially IPC_LOCK (#1671)
  * Revert "Add `CUSTOM_MACROS` to `ConfigMap`"
  * Add `CUSTOM_MACROS` to `ConfigMap`
  * Initialize kubeshark pinned eBPF resources inside init
    container (#1665)
  * Replace sniffer 30001 port with 48999 (#1670)
  * Add hub metrics port (#1666)
  * removed the loglevel flag (#1669)
  * Create save/activate/delete role scripting permissions
    (#1667)
  * Add --time param to pcapdump (#1664)
  * from debug to logLevel (#1668)
* Tue Dec 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 52.3.92:
  * :bookmark: Bump the Helm chart version to 52.3.92
  * change the tlx dissector name to tlsx (#1648)
  * Added LDAP support (#1647)
  * Default startup values change (#1646)
  * fixed a bug where a new script can't be added if (#1645)
  * Add permissions to watch namespaces (#1644)
* Mon Dec  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 52.3.91:
  * :bookmark: Bump the Helm chart version to 52.3.91
  * fixed a small issues in the Makefile
* Wed Nov 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 52.3.90:
  * Bump the Helm chart version to 52.3.90
  * updated `pcapdump` command's help starting deprecated the
    `export` command
  * Brought back `.gitignore`` after having been deleted due to a
    bad commit.
  * removed two binary files uploaded due to a bad earlier commit.
  * Fixed a bug in the Makefile
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 52.3.89:
  * :bookmark: Bump the Helm chart version to 52.3.89
  * if no scripting source folders, that's not an error
  * Remove pfring leftovers from ds (#1642)
  * Fix frontend port (#1641)
  * Added an option to provide multiple script sources. (#1640)
  * Remove PF_RING references  (#1638)
  * Watch cm creation and sync scripts (#1637)
  * Fix helm resource requests/limits templates (#1639)
* Sun Nov  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 52.3.88:
  * :bookmark: Bump the Helm chart version to 52.3.88
  * missing commit
  * Improved resource limits and requests Helm templating
  * Added an ability to override image names for a case, where when
    using a CI, one needs to use individual image names (#1636)
* Thu Oct 31 2024 opensuse_buildservice@ojkastl.de
- Update to version 52.3.87:
  * :bookmark: Bump the Helm chart version to 52.3.87
* Wed Oct 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 52.3.86:
  * removed debug comments
  * :bookmark: Bump the Helm chart version to 52.3.86
  * Revert "Set resource guard to true by default."
* Wed Oct 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 52.3.85:
  * :bookmark: Bump the Helm chart version to 52.3.85
  * fixed an issue that was added for debugging purposes
  * Set resource guard to true by default.
  * When compiling helm values from golang config structs, ignore
    local ~/.kubeshark/config.yaml file if one exists
  * Fixed the double action for commands: console and scripts, when
    running the proxyRunner
  * Revert "🐛 Prevent `hub` host-not-found nginx upstream error in
    `front` (#1628)" (#1633)
  * Removed the `timestamp>now()` fro the `globalFilter` flag.
  * remove `tcp` and `udp` dissectors by default
  * changed `tap.stopped` to `false` by default
  * scripting improvements
  * Add networkpolicies permissions (#1631)
* Fri Oct 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 52.3.84:
  * added timestamp>now() as a global filter
  * set `disableTlsLog` to `true` by default.
  * Hub default limit set to 5GB (an arbitrary number)
  * show filter presets by default
  * change CPU limit to no limit Change memory limit to 3Gi
  * scripting-revamp-1 (#1630)
  * Prevent `hub` host-not-found nginx upstream error in `front`
    (#1628)
  * fix lint issue
  * Added log lines for verbosity
  * Added the scripting `console` command functionality to the
    `tap` command Added both the `scripting` and `console` commands
    to the `proxy` command Added a `scripting.console`, a boolean
    value indicating whether the `console` functionality should be
    part of the `tap` and `proxy` commands
  * Improved the `console` command made it resilient to Websocket
    breaks and redeployment.
* Fri Oct 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 52.3.83:
  * :bookmark: Bump the Helm chart version to 52.3.83
  * :bookmark: Bump the Helm chart version to 72.3.83
  * Added some error and info log lines
  * Add `tap.presetFiltersChangingEnabled` helm value (#1627)
  * Set reasonable `pcapdump` defaults. Storage is now at 10%% of
    the Worker's allocated storage.
  * Tag Tracer as well as the other components upon a new release
  * Ensure `scripting` command watched only JS files
  * Feat pcapsaver (#1621)
  * emit tls item (#1625)
  * Update README with resource guard configuration (#1623)
  * Add resource guard flag (#1622)
  * Regenerate `values.yaml` and `complete.yaml`
  * Do not enable `-unixsocket` flag of worker if no tracer is
    running (#1619)
  * Fixed a bug in the `console` command, where the CLI couldn't
    connect to Hub as when the `url.URL` method was used, the Host
    included a path
  * Add list permissions for kubeshark service account (#1617)
  * Add `udp` to list of enabled dissectors (#1616)
  * Make the `scritps` command directly use the K8s API without
    requiring a connector to Hub (#1615)
  * Print instructions for running `kubectl port-forward` command
    in case of failure (#1614)
  * propagate host root to the tracer (#1613)
  * Fix `-staletimeout` worker command value (#1611)
  * Template the `-staletimeout` flag (#1610)
  * updated Grafana dahsboard
  * text change
  * text changes
* Mon Sep 23 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package kubeshark-cli: CLI for the API traffic analyzer for
  Kubernetes
